@@ -23,7 +23,9 @@ class ZebrunnerHandler(StreamHandler):
 
     def __init__(self) -> None:
         super().__init__()
-        self.api = ZebrunnerAPI()
+        self.api = ZebrunnerAPI(
+            zebrunner_context.settings.server.hostname, zebrunner_context.settings.server.access_token
+        )
         self.last_push = datetime.utcnow()
 
     def emit(self, record: LogRecord) -> None:
@@ -54,7 +56,7 @@ class ZebrunnerHandler(StreamHandler):
 
         """
         try:
-            if zebrunner_context.test_run_is_active and zebrunner_context.settings.send_logs:
+            if zebrunner_context.test_run_id and zebrunner_context.settings.send_logs:
                 self.api.send_logs(zebrunner_context.test_run_id, self.logs)
         except httpx.HTTPError as e:
             logging.error("Failed to send logs to zebrunner", exc_info=e)
